upoints.gpx.Trackpoint

Package upoints :: Module gpx :: Class Trackpoint |
[hide private]
[frames] | no frames]

# Class Trackpoint

     object --+
              |
    point.Point --+
                  |
           _GpxElem --+
                      |
                     Trackpoint

Class for representing a waypoint element from GPX data files

    >>> Trackpoint(52, 0)
    Trackpoint(52.0, 0.0, None, None)
    >>> Trackpoint(52, 0, None)
    Trackpoint(52.0, 0.0, None, None)
    >>> Trackpoint(52, 0, "name", "desc")
    Trackpoint(52.0, 0.0, 'name', 'desc')

Since: 0.10.0

Instance Methods | [hide private]
Inherited from `_GpxElem`: `__init__`, `__str__`, `togpx` Inherited from `point.Point`: `__dict__`, `__eq__`, `__hash__`, `__ne__`, `__repr__`, `__unicode__`, `bearing`, `destination`, `distance`, `final_bearing`, `forward`, `inverse`, `midpoint`, `sun_events`, `sunrise`, `sunset`, `to_grid_locator` Inherited from `point.Point` (private): `_set_location` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variables | [hide private]
| _elem_name = ``'``trkpt``'``

Instance Variables | [hide private]
| description Waypoint's description
| latitude Location's latitude
| longitude Locations's longitude
| name Waypoint's name
Inherited from `point.Point`: `rad_latitude`, `rad_longitude`, `timezone`, `units`

Properties | [hide private]
Inherited from `point.Point` (private): `_angle`, `_latitude`, `_longitude`, `_rad_latitude`, `_rad_longitude` Inherited from `object`: `__class__`